==> mfc-api-model-0.1.1-sources.jar: com/valor/mfc/vms/api/model/usercenter/UserInfo.java <==
package com.valor.mfc.vms.api.model.usercenter;

import com.valor.mfc.vms.api.model.common.AbstractPrintable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

public class UserInfo extends AbstractPrintable {

    private long uid;
    private String email;
    private String userName;
    private long userProperty;
    private String token;
    private String kbUserId;
    private String kbUserKey;
    private List<UserDevice> userDevices = new ArrayList<>();
    private long bizExpireTS = 0;
    private long bizAvailableTS = 0;
    private String bizExpireStr = "";
    private int bizRemainingDays = 0;
    private int trial = 0;
    private String product;
    private Long productId;
    //Record if account login in app.
    private boolean loginApp;
    private Date firstLoginAppDate;
    private String langWeb;

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public String getProduct() {
        return product;
    }

    public void setProduct(String product) {
        this.product = product;
    }

    public long getUid() {
        return uid;
    }

    public void setUid(long uid) {
        this.uid = uid;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public List<UserDevice> getUserDevices() {
        return userDevices;
    }

    public void setUserDevices(List<UserDevice> userDevices) {
        this.userDevices = userDevices;
    }

    public long getUserProperty() {
        return userProperty;
    }

    public void setUserProperty(long userProperty) {
        this.userProperty = userProperty;
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public String getKbUserId() {
        return kbUserId;
    }

    public void setKbUserId(String kbUserId) {
        this.kbUserId = kbUserId;
    }

    public String getKbUserKey() {
        return kbUserKey;
    }

    public void setKbUserKey(String kbUserKey) {
        this.kbUserKey = kbUserKey;
    }

    public long getBizExpireTS() {
        return bizExpireTS;
    }

    public void setBizExpireTS(long bizExpireTS) {
        this.bizExpireTS = bizExpireTS;
    }

    public String getBizExpireStr() {
        return bizExpireStr;
    }

    public void setBizExpireStr(String bizExpireStr) {
        this.bizExpireStr = bizExpireStr;
    }

    public long getBizAvailableTS() {
        return bizAvailableTS;
    }

    public void setBizAvailableTS(long bizAvailableTS) {
        this.bizAvailableTS = bizAvailableTS;
    }

    public int getBizRemainingDays() {
        return bizRemainingDays;
    }

    public void setBizRemainingDays(int bizRemainingDays) {
        this.bizRemainingDays = bizRemainingDays;
    }

    public int getTrial() {
        return trial;
    }

    public void setTrial(int trial) {
        this.trial = trial;
    }

    public boolean isLoginApp() {
        return loginApp;
    }

    public void setLoginApp(boolean loginApp) {
        this.loginApp = loginApp;
    }

    public Date getFirstLoginAppDate() {
        return firstLoginAppDate;
    }

    public void setFirstLoginAppDate(Date firstLoginAppDate) {
        this.firstLoginAppDate = firstLoginAppDate;
    }

    public String getLangWeb() {
        return langWeb;
    }

    public void setLangWeb(String langWeb) {
        this.langWeb = langWeb;
    }
}

==> mfc-api-model-0.1.2-sources.jar: com/valor/mfc/vms/api/model/usercenter/UserInfo.java <==
package com.valor.mfc.vms.api.model.usercenter;

import com.valor.mfc.vms.api.model.common.AbstractPrintable;

import java.util.*;

public class UserInfo extends AbstractPrintable {

    private long accountId;
    private int accountType;
    private int accountLoginType;
    private long uid;
    private String email;
    private String loginId;
    private String userName;
    private long userProperty;
    private String token;
    private String kbUserId;
    private String kbUserKey;
    private List<UserDevice> userDevices = new ArrayList<>();
    private long bizExpireTS = 0;
    private long bizAvailableTS = 0;
    private long bizRestTs = 0;
    private String bizExpireStr = "";
    private int bizRemainingDays = 0;
    private int trial = 0;
    private String product;
    private Map<String, String> products = new HashMap<>();
    private Long productId;
    //Record if account login in app.
    private boolean loginApp;
    private Date firstLoginAppDate;
    private String langWeb;
    private boolean getFreeTrial;
    private boolean unsubscribeEmail;
    private boolean renewing;
    private int serviceType;
    private String regIp;

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public String getProduct() {
        return product;
    }

    public void setProduct(String product) {
        this.product = product;
    }

    public long getUid() {
        return uid;
    }

    public void setUid(long uid) {
        this.uid = uid;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getLoginId() {
        return loginId;
    }

    public void setLoginId(String loginId) {
        this.loginId = loginId;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public List<UserDevice> getUserDevices() {
        return userDevices;
    }

    public void setUserDevices(List<UserDevice> userDevices) {
        this.userDevices = userDevices;
    }

    public long getUserProperty() {
        return userProperty;
    }

    public void setUserProperty(long userProperty) {
        this.userProperty = userProperty;
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public String getKbUserId() {
        return kbUserId;
    }

    public void setKbUserId(String kbUserId) {
        this.kbUserId = kbUserId;
    }

    public String getKbUserKey() {
        return kbUserKey;
    }

    public void setKbUserKey(String kbUserKey) {
        this.kbUserKey = kbUserKey;
    }

    public long getBizExpireTS() {
        return bizExpireTS;
    }

    public void setBizExpireTS(long bizExpireTS) {
        this.bizExpireTS = bizExpireTS;
    }

    public long getBizRestTs() {
        return bizRestTs;
    }

    public void setBizRestTs(long bizRestTs) {
        this.bizRestTs = bizRestTs;
    }

    public String getBizExpireStr() {
        return bizExpireStr;
    }

    public void setBizExpireStr(String bizExpireStr) {
        this.bizExpireStr = bizExpireStr;
    }

    public long getBizAvailableTS() {
        return bizAvailableTS;
    }

    public void setBizAvailableTS(long bizAvailableTS) {
        this.bizAvailableTS = bizAvailableTS;
    }

    public int getBizRemainingDays() {
        return bizRemainingDays;
    }

    public void setBizRemainingDays(int bizRemainingDays) {
        this.bizRemainingDays = bizRemainingDays;
    }

    public int getTrial() {
        return trial;
    }

    public void setTrial(int trial) {
        this.trial = trial;
    }

    public boolean isLoginApp() {
        return loginApp;
    }

    public void setLoginApp(boolean loginApp) {
        this.loginApp = loginApp;
    }

    public Date getFirstLoginAppDate() {
        return firstLoginAppDate;
    }

    public void setFirstLoginAppDate(Date firstLoginAppDate) {
        this.firstLoginAppDate = firstLoginAppDate;
    }

    public String getLangWeb() {
        return langWeb;
    }

    public void setLangWeb(String langWeb) {
        this.langWeb = langWeb;
    }

    public boolean isGetFreeTrial() {
        return getFreeTrial;
    }

    public void setGetFreeTrial(boolean getFreeTrial) {
        this.getFreeTrial = getFreeTrial;
    }

    public boolean isUnsubscribeEmail() {
        return unsubscribeEmail;
    }

    public void setUnsubscribeEmail(boolean unsubscribeEmail) {
        this.unsubscribeEmail = unsubscribeEmail;
    }

    public int getServiceType() {
        return serviceType;
    }

    public void setServiceType(int serviceType) {
        this.serviceType = serviceType;
    }

    public long getAccountId() {
        return accountId;
    }

    public void setAccountId(long accountId) {
        this.accountId = accountId;
    }

    public int getAccountType() {
        return accountType;
    }

    public void setAccountType(int accountType) {
        this.accountType = accountType;
    }

    public int getAccountLoginType() {
        return accountLoginType;
    }

    public void setAccountLoginType(int accountLoginType) {
        this.accountLoginType = accountLoginType;
    }

    public Map<String, String> getProducts() {
        return products;
    }

    public void setProducts(Map<String, String> products) {
        this.products = products;
    }

    public boolean isRenewing() {
        return renewing;
    }

    public void setRenewing(boolean renewing) {
        this.renewing = renewing;
    }

    public String getRegIp() {
        return regIp;
    }

    public void setRegIp(String regIp) {
        this.regIp = regIp;
    }
}
